// Kingdom of Kod
// ==============
// -Adventures of the heroes in the 'Manga Guide to Databases'

// -Filename: main.cpp
// -The program's entry point, and etc.

/*

DESIGN GOALS:
=============

-Primarily, to flesh out a screenplay scripting, animation, AI-inference, etc.,
system, using the ''Manga Guide to Databases'' characters, scenarios, and
topics as inspiration and guidance. Kind of like a 'living', interactive version
of the book's characters and stories.

  -Characters
  -Layouts
  -Props
  -Environments, Lighting, and Effects
  -Mesh generation for Blender
  -Automated CV-based sourcing for character designs directly from the manga
  -Properly-formatted script generation
  -Integrate with the RW Simulator or some other animation visualization system

-Secondarily, to design a JSON-based SQL database system to use with other
projects, such as the robowaifu access control AI project.

  -Use JSON as the data system
  -Support BSON binary storage/loading

-Book sauce:

  https://nostarch.com/mg_databases.htm

*/

#include <iostream>

#include "Action.hpp"
#include "Camera.hpp"
#include "Character.hpp"
#include "Dialog.hpp"
#include "Effect.hpp"
#include "Environment.hpp"
#include "Human.hpp"
#include "Light.hpp"
#include "Log.hpp"
#include "Production.hpp"
#include "Prop.hpp"
#include "Robowaifu.hpp"
#include "Scene.hpp"
#include "Script.hpp"
#include "Sequence.hpp"
#include "Shot.hpp"
#include "Timeline.hpp"

#include "rw_cli_args.hpp"

using std::cout;

/**-----------------------------------------------------------------------------
 * The program's entry point
 *
 * @param argc [IN] The CLI arguments count
 * @param argv [IN] The CLI arguments C-string array
 * @return The program's exit status
 *
 *
 */
int main(int argc, char** argv) {
  rw::parse_args(argc, argv);

  cout << "Hello Anon, from the Kingdom of Kod!\n";

  Human       human{};
  Character   character{};
  Script      script{};
  Log         log{};
  Dialog      dialog{};
  Action      action{};
  Environment environment{};
  Prop        prop{};
  Scene       scene{};
  Sequence    sequence{};
  Shot        shot{};
  Light       light{};
  Production  production{};
  Camera      camera{};
  Effect      effect{};
  Timeline    timeline{};
  Robowaifu   robowaifu{};

  cout << "human.name(): '" << human.name() << "'\n";
  cout << "human.posn(): '" << human.posn() << "'\n";

  cout << "character.name(): '" << character.name() << "'\n";
  cout << "character.posn(): '" << character.posn() << "'\n";

  cout << "script.name(): '" << script.name() << "'\n";
  cout << "script.posn(): '" << script.posn() << "'\n";

  cout << "log.name(): '" << log.name() << "'\n";
  cout << "log.posn(): '" << log.posn() << "'\n";

  cout << "dialog.name(): '" << dialog.name() << "'\n";
  cout << "dialog.posn(): '" << dialog.posn() << "'\n";

  cout << "action.name(): '" << action.name() << "'\n";
  cout << "action.posn(): '" << action.posn() << "'\n";

  cout << "environment.name(): '" << environment.name() << "'\n";
  cout << "environment.posn(): '" << environment.posn() << "'\n";

  cout << "prop.name(): '" << prop.name() << "'\n";
  cout << "prop.posn(): '" << prop.posn() << "'\n";

  cout << "scene.name(): '" << scene.name() << "'\n";
  cout << "scene.posn(): '" << scene.posn() << "'\n";

  cout << "sequence.name(): '" << sequence.name() << "'\n";
  cout << "sequence.posn(): '" << sequence.posn() << "'\n";

  cout << "shot.name(): '" << shot.name() << "'\n";
  cout << "shot.posn(): '" << shot.posn() << "'\n";

  cout << "light.name(): '" << light.name() << "'\n";
  cout << "light.posn(): '" << light.posn() << "'\n";

  cout << "production.name(): '" << production.name() << "'\n";
  cout << "production.posn(): '" << production.posn() << "'\n";

  cout << "camera.name(): '" << camera.name() << "'\n";
  cout << "camera.posn(): '" << camera.posn() << "'\n";

  cout << "effect.name(): '" << effect.name() << "'\n";
  cout << "effect.posn(): '" << effect.posn() << "'\n";

  cout << "timeline.name(): '" << timeline.name() << "'\n";
  cout << "timeline.posn(): '" << timeline.posn() << "'\n";

  cout << "robowaifu.name(): '" << robowaifu.name() << "'\n";
  cout << "robowaifu.posn(): '" << robowaifu.posn() << "'\n";
}

// Copyright (2021)
// License MIT (Expat) https://opensource.org/licenses/MIT
